# UnderStar-OS
A discord bot OS.
Discord : https://discord.gg/CrEVTwjEvT

## Docker use (experimental)
Download source code and excecute `docker image build -t understar-os .` in the CMD from the project directory